import * as _codemirror_view from '@codemirror/view';
import { ViewPlugin, EditorView, ViewUpdate } from '@codemirror/view';
import { Extension } from '@codemirror/state';

interface PlaceholderConfig {
    id: string;
    begin: string;
    end: string;
    placeholder: string;
}
interface SlotRegion {
    id: string;
    beginPos: number;
    endPos: number;
}
interface PlaceholderTheme {
    placeholder?: Record<string, string>;
    slotContent?: Record<string, string>;
    placeholderBegin?: Record<string, string>;
    placeholderEnd?: Record<string, string>;
}

declare function createPlaceholderPlugin(config?: PlaceholderConfig[]): ViewPlugin<{
    decorations: _codemirror_view.DecorationSet;
    correctCursorPosition(view: EditorView, pos: number): number;
    createDecorations(view: EditorView): _codemirror_view.DecorationSet;
    update(update: ViewUpdate): void;
}>;

declare function createPlaceholderTheme(customTheme?: PlaceholderTheme): Extension;

/**
 * 解析文本中的占位符内容，返回纯文本
 * @param text 包含占位符的原始文本
 * @param config 占位符配置数组
 * @returns 处理后的纯文本，只包含占位符内容
 */
declare function parsePlaceholderContent(text: string, config: PlaceholderConfig[]): string;

export { PlaceholderConfig, PlaceholderTheme, SlotRegion, createPlaceholderPlugin, createPlaceholderTheme, parsePlaceholderContent };
